Audit logging backends.
This module provides various backends for storing audit logs:
FileLogger: Plain text file loggingJsonFileLogger: JSON structured logging with rotationAsyncLogger: Non-blocking async wrapper
Structs
- Async
Logger - Async wrapper that provides non-blocking logging.
- Async
Logger Builder - A builder for creating async loggers with custom configuration.
- File
Logger - A simple file-based audit logger.
- Json
File Logger - JSON file logger with rotation support.
- Rotation
Config - Configuration for log rotation.
Enums
- Rotation
Policy - Rotation policy for log files.