pub struct AsyncLogger { /* private fields */ }Expand description
Async wrapper that provides non-blocking logging.
Events are sent to a background task that handles the actual logging, allowing the caller to continue without waiting for I/O.
Implementations
Sourceimpl AsyncLogger
impl AsyncLogger
Sourcepub fn new<L: AuditLogger + 'static>(inner: L, config: &AuditConfig) -> Self
pub fn new<L: AuditLogger + 'static>(inner: L, config: &AuditConfig) -> Self
Create a new async logger wrapping the given backend.
Sourcepub fn wrap<L: AuditLogger + 'static>(inner: L) -> Self
pub fn wrap<L: AuditLogger + 'static>(inner: L) -> Self
Create with default buffer size.
Sourcepub async fn shutdown(&self) -> Result<(), AuditError>
pub async fn shutdown(&self) -> Result<(), AuditError>
Gracefully shutdown the logger.